==> gem_0.77.orig.tar.gz: gem-0.77.orig/src/Geos/cone.cpp <==
////////////////////////////////////////////////////////
//
// GEM - Graphics Environment for Multimedia
//
// mdanks@cybermed.ucsd.edu
//
// Implementation file
//
//    Copyright (c) 1997-1998 Mark Danks.
//    For information on usage and redistribution, and for a DISCLAIMER OF ALL
//    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
//
/////////////////////////////////////////////////////////

#include "cone.h"

CPPEXTERN_NEW_WITH_ONE_ARG(cone, t_floatarg, A_DEFFLOAT)

/////////////////////////////////////////////////////////
//
// cone
//
/////////////////////////////////////////////////////////
// Constructor
//
/////////////////////////////////////////////////////////
cone :: cone(t_floatarg size)
      : GemGluObj(size)
{ }

/////////////////////////////////////////////////////////
// Destructor
//
/////////////////////////////////////////////////////////
cone :: ~cone()
{ }

/////////////////////////////////////////////////////////
// render
//
/////////////////////////////////////////////////////////
void cone :: render(GemState *state)
{
    // lighting
    if (state->lighting)
    {
    	// normals
    	if (state->smooth) gluQuadricNormals(m_thing, GLU_SMOOTH);
    	else gluQuadricNormals(m_thing, GLU_FLAT);
    }
    
    // texture mapping
    if (state->texture) gluQuadricTexture(m_thing, GL_TRUE);
    else gluQuadricTexture(m_thing, GL_FALSE);
    
    gluQuadricDrawStyle(m_thing, m_drawType);
    gluCylinder(m_thing, m_size, 0, m_size * 2, m_numSlices, m_numSlices);
}

/////////////////////////////////////////////////////////
// static member functions
//
/////////////////////////////////////////////////////////
void cone :: obj_setupCallback(t_class *)
{ }

==> gem_0.81.orig.tar.gz: gem-0.81/src/Geos/cone.cpp <==
////////////////////////////////////////////////////////
//
// GEM - Graphics Environment for Multimedia
//
// mark@danks.org
//
// Implementation file
//
//    Copyright (c) 1997-1998 Mark Danks.
//    For information on usage and redistribution, and for a DISCLAIMER OF ALL
//    WARRANTIES, see the file, "GEM.LICENSE.TERMS" in this distribution.
//
/////////////////////////////////////////////////////////

#include "cone.h"

CPPEXTERN_NEW_WITH_ONE_ARG(cone, t_floatarg, A_DEFFLOAT)

/////////////////////////////////////////////////////////
//
// cone
//
/////////////////////////////////////////////////////////
// Constructor
//
/////////////////////////////////////////////////////////
cone :: cone(t_floatarg size)
      : GemGluObj(size)
{ }

/////////////////////////////////////////////////////////
// Destructor
//
/////////////////////////////////////////////////////////
cone :: ~cone()
{ }

/////////////////////////////////////////////////////////
// render
//
/////////////////////////////////////////////////////////
void cone :: render(GemState *state)
{
    // lighting
    if (state->lighting)
    {
    	// normals
    	if (state->smooth) gluQuadricNormals(m_thing,(enum GLenum) GLU_SMOOTH);
    	else gluQuadricNormals(m_thing, (enum GLenum)GLU_FLAT);
    }
    
    // texture mapping
    if (state->texture) gluQuadricTexture(m_thing, GL_TRUE);
    else gluQuadricTexture(m_thing, GL_FALSE);
    
    gluQuadricDrawStyle(m_thing, m_drawType);
    gluCylinder(m_thing, m_size, 0, m_size * 2, m_numSlices, m_numSlices);
}

/////////////////////////////////////////////////////////
// static member functions
//
/////////////////////////////////////////////////////////
void cone :: obj_setupCallback(t_class *)
{ }
